EasyExtend.langlets.p4d.xmlutils.Parser

Package EasyExtend :: Package langlets :: Package p4d :: Module xmlutils :: Class Parser |
[hide private]
[frames] | no frames]

# Class Parser

    object --+
             |
            Parser

Known Subclasses:
  - ExpatParser

Instance Methods | [hide private]
__init__(self) x.__init__(...) initializes x; see x.__class__.__doc__ for signature |
parse(self, s) |
start_element(self, name, attrs) |
char_data(self, data) |
end_element(self, name) |
default(self, data) |
start_cdata(self) |
end_cdata(self) |
comment(self, data) |
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)